# jses_environment
Baixar, instalar e configurar um ambiente para realizar engenharia e ciência de dados no Google Colab, utilizando Java, Spark e Elasticsearch.
Download, install and configure an environment to perform data engineering and science on Google Colab, using Java, Spark and Elasticsearch.
